@@ -1,23 +1,10 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*-
  *
- * Copyright (C) 2008-2011 Red Hat, Inc.
+ * Copyright (C) 2008-2012 Red Hat, Inc.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * Licensed under GPL version 2 or later.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
- *
- * Author: David Zeuthen <davidz@redhat.com>
+ * Author: David Zeuthen <zeuthen@gmail.com>
  */
 
 #include "config.h"
@@ -29,7 +16,6 @@
 #include "gduapplication.h"
 #include "gduwindow.h"
 #include "gdudisksettingsdialog.h"
-#include "gduutils.h"
 
 /* ---------------------------------------------------------------------------------------------------- */
 
@@ -370,9 +356,9 @@ on_set_configuration_cb (GObject      *source_object,
                                                    res,
                                                    &error))
     {
-      gdu_window_show_error (data->window,
-                             _("Error setting configuration"),
-                             error);
+      gdu_utils_show_error (GTK_WINDOW (data->window),
+                            _("Error setting configuration"),
+                            error);
       g_clear_error (&error);
       goto out;
     }
